# this script gets included by config_sessions

PLUGIN_NAME="usbip"
PLUGIN_MENUITEM_NAME=""
PLUGIN_MENUITEM_EXEC=""
PLUGIN_MENUITEM_PARAM=""
PLUGIN_MENUITEM_WORKDIR=""
PLUGIN_MENUITEM_ICON=""

PLUGIN_AUTOSTART=0

PLUGIN_PACKAGES="sysfsutils usbip"

# include alx functions
source /etc/alxconfig-ng/config.rc
source /etc/alxconfig-ng/serial
source ${ALX_FUNCTIONS}/common
source ${ALX_FUNCTIONS}/mysqlfunctions
# missing colors
COLRED="\033[1;6m\033[31m"
COLDEFAULT="\033[0m"

die()
{
	echo "Error: $@"
	echo -e "${COLRED}Plugin \"${PLUGIN_NAME}\" will be disabled.${COLDEFAULT}"
	# disable services
	rc-config del usbipd > /dev/null
	rc-config del usbipdevd > /dev/null
	exit 1
}

install_plugin()
{
	local i
	for i in ${PLUGIN_PACKAGES}
	do
		if [[ -z $(magequery -n ${i}) ]]
		then
			MAGE_BOOTSTRAP=true mage install ${i}
			mage clean
		fi
	done
}

setup_plugin()
{
	evaluate_table plugin_usbip

	# sanitize variables
	[[ -z ${plugin_usbip_device_id} ]] && die "device_id variable is empty"
	[[ -z ${plugin_usbip_polling_time} ]] && die "polling_time  variable is empty"

	[[ ! -d /etc/conf.d ]] && install /etc/conf.d
	local CONFIG="/etc/conf.d/usbipdevd"
	addconfig "USBIP_DEVICE_ID=\"${plugin_usbip_device_id}\""
	addconfig "USBIP_POLLING_TIME=\"${plugin_usbip_polling_time}\""

	# add to runlevels
	rc-config add usbipd > /dev/null
	rc-config add usbipdevd > /dev/null
}

# create desktop buttons
create_menuitem()
{
	# don't touch these echo, define variables above
	echo "PLUGIN_MENUITEM_NAME=\"${PLUGIN_MENUITEM_NAME}\""
	echo "PLUGIN_MENUITEM_EXEC=\"${PLUGIN_MENUITEM_EXEC}\""
	echo "PLUGIN_MENUITEM_PARAM=\"${PLUGIN_MENUITEM_PARAM}\""
	echo "PLUGIN_MENUITEM_WORKDIR=\"${PLUGIN_MENUITEM_WORKDIR}\""
	echo "PLUGIN_MENUITEM_ICON=\"${PLUGIN_MENUITEM_ICON}\""
}

autostart_plugin()
{
	echo "PLUGIN_AUTOSTART=\"${PLUGIN_AUTOSTART}\""
	echo "PLUGIN_MENUITEM_NAME=\"${PLUGIN_MENUITEM_NAME}\""
}

uninstall_plugin()
{
	local i
	for i in ${PLUGIN_PACKAGES}
	do
		if [[ -n $(magequery -n ${i}) ]]
		then
			MAGE_BOOTSTRAP=true mage uninstall ${i}
			mage clean
		fi
	done

	mage clean
}

case $1 in
	install) install_plugin ;;
	setup) setup_plugin ;;
	menuitem) create_menuitem ;;
	autostart) autostart_plugin ;;
	uninstall) uninstall_plugin ;;
	*) echo "PLUGIN '${PLUGIN_NAME}': unkown operation '$1'" ;;
esac
